%global proton_datadir %{_datadir}/proton-%{version}

%if 0%{?fedora}
%global gem_name qpid_proton
%endif

# per https://fedoraproject.org/wiki/Packaging:AutoProvidesAndRequiresFiltering#Preventing_files.2Fdirectories_from_being_scanned_for_deps_.28pre-scan_filtering.29
%global __provides_exclude_from ^%{_datadir}/proton-%{version}/examples/.*$
%global __requires_exclude_from ^%{_datadir}/proton-%{version}/examples/.*$

#  for older rpm, like el6, https://fedoraproject.org/wiki/EPEL:Packaging_Autoprovides_and_Requires_Filtering#Perl
%{?filter_setup:
%filter_provides_in %{_datadir}/proton-%{version}/examples/
%filter_requires_in %{_datadir}/proton-%{version}/examples/
%filter_setup
}

Name:           qpid-proton
Version:        0.13.0
Release:        4%{?dist}
Group:          System Environment/Libraries
Summary:        A high performance, lightweight messaging library

License:        ASL 2.0
URL:            http://qpid.apache.org/proton/

Source0:        %{name}-%{version}.tar.gz
BuildRequires:  gcc
BuildRequires:  cmake
BuildRequires:  swig
BuildRequires:  pkgconfig
BuildRequires:  doxygen
BuildRequires:  libuuid-devel
BuildRequires:  openssl-devel
%if 0%{?fedora} 
BuildRequires:  python2-devel
BuildRequires:  python3-devel
%endif
%if 0%{?rhel}
BuildRequires:  python-devel
%endif
BuildRequires:  epydoc
%if 0%{?fedora}
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  perl(Test::Exception)
BuildRequires:  perl(Test::More)
BuildRequires:  cyrus-sasl-devel
%endif

Patch0:         proton.patch

%description
Proton is a high performance, lightweight messaging library. It can be used in
the widest range of messaging applications including brokers, client libraries,
routers, bridges, proxies, and more. Proton is based on the AMQP 1.0 messaging
standard. Using Proton it is trivial to integrate with the AMQP 1.0 ecosystem
from any platform, environment, or language.


%package c
Group:     System Environment/Libraries
Summary:   C libraries for Qpid Proton
Requires:  cyrus-sasl-lib
Obsoletes: qpid-proton

%description c
%{summary}.


%files c
%defattr(-,root,root,-)
%dir %{proton_datadir}
%doc %{proton_datadir}/LICENSE
%doc %{proton_datadir}/README*
%doc %{proton_datadir}/TODO
%{_libdir}/libqpid-proton.so.*

%post c -p /sbin/ldconfig

%postun c -p /sbin/ldconfig

%if 0%{?rhel}
%package   cpp
Group:     System Environment/Libraries
Summary:   C++ libraries for Qpid Proton
Requires:  qpid-proton-c%{?_isa} = %{version}-%{release} 

%description cpp
%{summary}.

%files cpp
%defattr(-,root,root,-)
%dir %{proton_datadir}
%doc %{proton_datadir}/LICENSE
%doc %{proton_datadir}/README*
%doc %{proton_datadir}/TODO
%{_libdir}/libqpid-proton-cpp.so.*

%post cpp -p /sbin/ldconfig

%postun cpp -p /sbin/ldconfig
%endif

%package c-devel
Group:     Development/System
Requires:  qpid-proton-c%{?_isa} = %{version}-%{release}
Summary:   Development libraries for writing messaging apps with Qpid Proton
Obsoletes: qpid-proton-devel

%description c-devel
%{summary}.

%files c-devel
%defattr(-,root,root,-)
%{_includedir}/proton
%if 0%{?rhel} 
%exclude %{_includedir}/proton/*.hpp
%endif
%{_libdir}/libqpid-proton.so
%{_libdir}/pkgconfig/libqpid-proton.pc
%{_libdir}/cmake/Proton


%if 0%{?rhel}
%package cpp-devel
Group:     Development/System
Requires:  qpid-proton-cpp%{?_isa} = %{version}-%{release}
Requires:  qpid-proton-c-devel%{?_isa} = %{version}-%{release}
Summary:   Development libraries for writing messaging apps with Qpid Proton

%description cpp-devel
%{summary}.

%files cpp-devel
%defattr(-,root,root,-)
%{_includedir}/proton/*.hpp
%{_libdir}/pkgconfig/libqpid-proton-cpp.pc
%{_libdir}/libqpid-proton-cpp.so
%{_libdir}/cmake/ProtonCpp
%endif


%package c-devel-docs
Summary:   Documentation for the C development libraries for Qpid Proton
BuildArch: noarch
Obsoletes:  qpid-proton-c-devel-doc
%description c-devel-docs
%{summary}.

%files c-devel-docs
%defattr(-,root,root,-)
%doc %{proton_datadir}/docs/api-c
%doc %{proton_datadir}/examples
%exclude %{_datadir}/proton-%{version}/examples/cpp
%exclude %{_datadir}/proton-%{version}/examples/go
%exclude %{_datadir}/proton-%{version}/examples/java
%exclude %{_datadir}/proton-%{version}/examples/javascript
%exclude %{_datadir}/proton-%{version}/examples/php
%exclude %{_datadir}/proton-%{version}/examples/python
%exclude %{_datadir}/proton-%{version}/examples/ruby
%exclude %{_datadir}/proton-%{version}/examples/perl
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/recv
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/recv-async
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/send
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/send-async
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/CMakeFiles
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/Makefile
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/cmake_install.cmake
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/CTestTestfile.cmake
%exclude %{_datadir}/proton-%{version}/examples/engine/java


%if 0%{?rhel}
%package   cpp-devel-docs
Summary:   Documentation for the C++ development libraries for Qpid Proton
BuildArch: noarch
Obsoletes:  qpid-proton-cpp-devel-doc

%description cpp-devel-docs
%{summary}.

%files cpp-devel-docs
%defattr(-,root,root,-)
%{proton_datadir}/docs/api-cpp
%doc %{proton_datadir}/examples
%exclude %{_datadir}/proton-%{version}/examples/c
%exclude %{_datadir}/proton-%{version}/examples/go
%exclude %{_datadir}/proton-%{version}/examples/java
%exclude %{_datadir}/proton-%{version}/examples/javascript
%exclude %{_datadir}/proton-%{version}/examples/php
%exclude %{_datadir}/proton-%{version}/examples/python
%exclude %{_datadir}/proton-%{version}/examples/ruby
%exclude %{_datadir}/proton-%{version}/examples/perl
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/recv
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/recv-async
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/send
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/send-async
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/CMakeFiles
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/Makefile
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/cmake_install.cmake
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/CTestTestfile.cmake
%exclude %{_datadir}/proton-%{version}/examples/engine
%endif


%package -n python-qpid-proton
Group:    System Environment/Libraries
Summary:  Python language bindings for the Qpid Proton messaging framework

Requires: qpid-proton-c%{?_isa} = %{version}-%{release}
Requires: python

%description -n python-qpid-proton
%{summary}.

%files -n python-qpid-proton
%defattr(-,root,root,-)
%{python_sitearch}/_cproton.so
%{python_sitearch}/cproton.*
%{python_sitearch}/proton/*


%if 0%{?fedora}
%package -n python3-qpid-proton
Group:    System Environment/Libraries
Summary:  Python language bindings for the Qpid Proton messaging framework
%{?python_provide:%python_provide python3-qpid-proton}

Requires: qpid-proton-c%{?_isa} = %{version}-%{release}

%description -n python3-qpid-proton
%{summary}.

%files -n python-qpid-proton
%defattr(-,root,root,-)
%{python2_sitearch}/*

%files -n python3-qpid-proton
%defattr(-,root,root,-)
%{python3_sitearch}/*
%endif

%package -n python-qpid-proton-docs
Group:     Documentation
Summary:   Documentation for the Python language bindings for Qpid Proton
BuildArch: noarch
Obsoletes:  python-qpid-proton-doc

%description -n python-qpid-proton-docs
%{summary}.

%files -n python-qpid-proton-docs
%defattr(-,root,root,-)
%doc %{proton_datadir}/docs/api-py
%doc %{proton_datadir}/examples/python


%if 0%{?fedora}
%package -n perl-qpid-proton
Summary: Perl language bindings for Qpid Proton messaging framework

Requires:  perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires:  qpid-proton-c = %{version}-%{release}

%description -n perl-qpid-proton
%{summary}.

%files -n perl-qpid-proton
%doc LICENSE TODO README*
%{perl_vendorarch}/*
%endif


%prep
%setup -q -n %{name}-%{version}
%patch0 -p1

%build

%if 0%{?fedora}
%cmake \
    -DPROTON_DISABLE_RPATH=true \
    -DBUILD_RUBY=OFF \
    -DBUILD_PHP=OFF \
    -DSYSINSTALL_PYTHON=1 \
    -DSYSINSTALL_PERL=1 \
    .
%endif
%if 0%{?rhel}
%cmake -DPROTON_DISABLE_RPATH=true \
       -DCMAKE_EXE_LINKER_FLAGS="-Wl,-z,relro,-z,now" \
       -DCMAKE_SHARED_LINKER_FLAGS="-Wl,-z,relro" \
       -DCMAKE_MODULE_LINKER_FLAGS="-Wl,-z,relro" \
       -DSYSINSTALL_BINDINGS=ON \
       -DBUILD_RUBY=OFF \
       -DBUILD_PERL=OFF \
       .
%endif

make all docs %{?_smp_mflags}
%if 0%{?fedora}
(cd proton-c/bindings/python; %py3_build)
%endif

%install
%make_install
%if 0%{?fedora}
(cd proton-c/bindings/python; %py3_install)
%endif

CPROTON_BUILD=$PWD . ./config.sh

chmod +x %{buildroot}%{python_sitearch}/_cproton.so
find %{buildroot}%{proton_datadir}/examples/ -type f | xargs chmod -x 

# clean up files that are not shipped
rm -rf %{buildroot}%{_exec_prefix}/bindings
rm -rf %{buildroot}%{_libdir}/java
rm -rf %{buildroot}%{_libdir}/libproton-jni.so
rm -rf %{buildroot}%{_datarootdir}/java
rm -rf %{buildroot}%{_libdir}/proton.cmake
%if 0%{?fedora}
rm -rf %{buildroot}%{_libdir}/cmake/ProtonCpp
rm -rf %{buildroot}%{_libdir}/*cpp*
rm -rf %{buildroot}%{_libdir}/pkgconfig/libqpid-proton-cpp.pc
rm -rf %{buildroot}%{proton_datadir}/docs/api-cpp
%endif
%if 0%{?rhel}
rm -rf %{buildroot}%{_libdir}/perl5
rm -rf %{buildroot}%{_libdir}/php
rm -rf %{buildroot}%{_libdir}/ruby
rm -rf %{buildroot}%{_datarootdir}/php
rm -rf %{buildroot}%{_datarootdir}/perl5
rm -rf %{buildroot}%{_datarootdir}/ruby
rm -rf %{buildroot}%{_sysconfdir}/php.d
%endif

%check
%if 0%{?fedora} 
# check perl bindings
pushd proton-c/bindings/perl
make test
popd
%endif

%changelog
* Fri Jun 17 2016 Irina Boverman <iboverma@redhat.com> - 0.13.0-4
- Replaced "Provides" with "Obsoletes"

* Wed Jun 15 2016 Irina Boverman <iboverma@redhat.com> - 0.13.0-2
- Rebased to 0.13.0 GA version
- Changed *doc to *docs, moved examples to *docs
- Resolved ENTMQCL-367

* Tue May 17 2016 Irina Boverman <iboverma@redhat.com> - 0.13.0-1
- Rebased to 0.13.0 Beta

* Wed Mar 23 2016 Irina Boverman <iboverma@redhat.com> - 0.12.1-1
- Rebased to 0.12.1

* Thu Feb 18 2016 Irina Boverman <iboverma@redhat.com> - 0.12.0-1
- Rebased to 0.12.0

* Thu Jan 21 2016 Irina Boverman <iboverma@redhat.com> - 0.11.1-1
- Rebased to 0.11.1

* Thu Dec  3 2015 Irina Boverman <iboverma@redhat.com> - 0.11.0-1
- Rebased to 0.11.0

* Thu Sep  3 2015 Irina Boverman <iboverma@redhat.com> - 0.10-2
- Added dependency on cyrus-sasl-devel and cyrus-sasl-lib
- Added 0001-PROTON-974-Accept-a-single-symbol-in-SASL-mechs-fram.patch

* Mon Aug 17 2015 Irina Boverman <iboverma@redhat.com> - 0.10-1
- Rebased to 0.10 proton release

* Wed Jun  3 2015 Irina Boverman <iboverma@redhat.com> - 0.9-4
- Added PROTON-858-fix-deletion-of-entries-from-map-to-.patch

* Thu May  7 2015 Irina Boverman <iboverma@redhat.com> - 0.9-3
- Rebased to 0.9.1 upstream

* Tue Mar 31 2015 Irina Boverman <iboverma@redhat.com> - 0.9-2
- Rebased to final 0.9 upstream

* Tue Mar  3 2015 Irina Boverman <iboverma@redhat.com> - 0.9-1.20150223
- Revised spec file to exclude generated and binary files from
  examples/c/messender directory

* Mon Feb 23 2015 Irina Boverman <iboverma@redhat.com> - 0.9-1.20150223
- Rebased to upstream snapshot 92d0499

* Thu Feb 19 2015 Irina Boverman <iboverma@redhat.com> - 0.9-1.20150219
- Removed perl examples

* Wed Feb 18 2015 Irina Boverman <iboverma@redhat.com> - 0.9-1.20150218.1
- Rebased to upstream snapshot ae49e3a

* Fri Nov  7 2014 Irina Boverman <iboverma@redhat.com> - 0.7-5
- Resolved: 1153769

* Thu Sep  4 2014 Irina Boverman <iboverma@redhat.com> - 0.7-4
- Resolved: 1126074

* Fri Aug  1 2014 Irina Boverman <iboverma@redhat.com> - 0.7-3
- Resolved: 1109320

* Thu May 29 2014 Irina Boverman <iboverma@redhat.com> - 0.7-2
- Add Visual-Studio-2008 patch

* Thu May  1 2014 Irina Boverman <iboverma@redhat.com> - 0.7-1
- Rebase to 0.7

* Fri Apr  4 2014 Irina Boverman <iboverma@redhat.com> - 0.6-2
- Added a patch to resolve bz 1077384

* Thu Dec 19 2013 Irina Boverman <iboverma@redhat.com> - 0.6-1
- Rebasing to 0.6-rc3

* Fri Nov 15 2013 Irina Boverman <iboverma@redhat.com> - 0.5-9
- Additional fixes for 1023639

* Wed Nov  6 2013 Irina Boverman <iboverma@redhat.com> - 0.5-8
- Resolved 1023639

* Thu Sep 26 2013 Irina Boverman <iboverma@redhat.com> - 0.5-6
- Added changes required to fix bz 995554

* Mon Sep 23 2013 Irina Boverman <iboverma@redhat.com> - 0.5-5
- Changed spec file to remove additional items

* Thu Sep 19 2013 Irina Boverman <iboverma@redhat.com> - 0.5-4
- Changed python-qpid-proton-doc sub-package to noarch

* Tue Sep 17 2013 Irina Boverman <iboverma@redhat.com> - 0.5-3
- Added qpid-proton-c-devel-doc/noarch package to resolve bz 1005058

* Wed Aug 28 2013 Irina Boverman <iboverma@redhat.com> - 0.5-2
- Built from mrg-messaging-3-rhel-6 branch

* Wed Aug 28 2013 Irina Boverman <iboverma@redhat.com> - 0.5-1
- Revised to Qpid Proton 0.5 version
- Resolves bz: 1002290

* Wed Apr 10 2013 Irina Boverman <iboverma@redhat.com> - 0.4-2.2
- Initial packaging of the Qpid Proton for a product.

* Fri Apr  5 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.4-2.2
- Added Obsoletes and Provides for packages whose names changed.
- Resolves: BZ#948784

* Mon Apr  1 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.4-2.1
- Fixed the dependencies for qpid-proton-devel and python-qpid-proton.

* Thu Mar 28 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.4-2
- Moved all C libraries to the new qpid-proton-c subpackage.

* Wed Mar 13 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.4-1
- Rebased on Proton 0.4.
- On EL6 BR pulls in Cmake 2.8 on PPC/PPC64.

* Thu Feb 21 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.3-4
- Fixes copying nested data.
- PROTON-246, PROTON-230

* Mon Jan 28 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.3-3
- Fixes build failure on non-x86 platforms.
- Resolves: BZ#901526

* Fri Jan 25 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.3-2
- Fixes build failure on non-x86 platforms.
- Resolves: BZ#901526

* Wed Jan 16 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.3-1
- Rebased on Proton 0.3.

* Fri Dec 28 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2.4
- Moved ownership of the docs dir to the docs package.

* Wed Dec 19 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2.3
- Fixed package dependencies, adding the release macro.

* Mon Dec 17 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2.2
- Fixed subpackage dependencies on main package.
- Removed accidental ownership of /usr/include.

* Thu Dec 13 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2.1
- Remove BR for ruby-devel.
- Removed redundant package name from summary.
- Removed debugging artifacts from specfile.
- Moved unversioned library to the -devel package.
- Added dependency on main package to -devel.
- Fixed directory ownerships.

* Fri Nov 30 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2
- Removed BR on help2man.
- Added patch for generated manpage.

* Mon Nov  5 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-1
- Initial packaging of the Qpid Proton.
